Module cache

Module cache 

Cache layer for liquid cache.

Re-exports

pub use cache_policies::CachePolicy;

Modules

cache_policies
Cache policies for liquid cache.
squeeze_policies
Squeeze policies for liquid cache.

Structs

BlockingIoContext
A blocking implementation of IoContext that uses the default compressor. This is used for testing purposes as all io operations are blocking.
CacheStats
Snapshot of cache statistics.
CacheStorage
Cache storage for liquid cache.
CacheStorageBuilder
Builder for CacheStorage.
DefaultIoContext
A default implementation of IoContext that uses the default compressor.
EntryID
EntryID is a unique identifier for a batch of rows, i.e., the cache key.
LiquidCompressorStates
States for liquid compressor.
RuntimeStats
Atomic runtime counters for cache API calls.
RuntimeStatsSnapshot
Immutable snapshot of RuntimeStats.

Enums

CachedBatch
Cached batch.
CachedBatchType
The type of the cached batch.
GetWithPredicateResult
The result of predicate pushdown.

Traits

IoContext
A trait for objects that can handle IO operations for the cache.

Functions

transcode_liquid_inner
This method is used to transcode an arrow array into a liquid array.