pub enum GetWithPredicateResult {
Evaluated(BooleanArray),
Filtered(ArrayRef),
}Expand description
The result of predicate pushdown.
Variants
Evaluated(BooleanArray)
The predicate is evaluated on the filtered data and the result is a boolean buffer.
Filtered(ArrayRef)
The predicate is not evaluated but data is filtered.