Cache layer for liquid cache.
Re-exports
pub use cache_policies::CachePolicy;
Modules
- cache_
policies - Cache policies for liquid cache.
- squeeze_
policies - Squeeze policies for liquid cache.
Structs
- Blocking
IoContext - A blocking implementation of IoContext that uses the default compressor. This is used for testing purposes as all io operations are blocking.
- Cache
Stats - Snapshot of cache statistics.
- Cache
Storage - Cache storage for liquid cache.
- Cache
Storage Builder - Builder for CacheStorage.
- Default
IoContext - A default implementation of IoContext that uses the default compressor.
- EntryID
- EntryID is a unique identifier for a batch of rows, i.e., the cache key.
- Liquid
Compressor States - States for liquid compressor.
- Runtime
Stats - Atomic runtime counters for cache API calls.
- Runtime
Stats Snapshot - Immutable snapshot of
RuntimeStats.
Enums
- Cached
Batch - Cached batch.
- Cached
Batch Type - The type of the cached batch.
- GetWith
Predicate Result - The result of predicate pushdown.
Traits
- IoContext
- A trait for objects that can handle IO operations for the cache.
Functions
- transcode_
liquid_ inner - This method is used to transcode an arrow array into a liquid array.